@@ -3,11 +3,14 @@ modems = {
         "EC25": { # Modem Name
             "0125": ["02"] # USB_COMPOSITION_ID
         },
+        "EC21": { # Modem Name
+            "0121": ["02"] # USB_COMPOSITION_ID
+        },
         "BG96": { # Modem Name
             "0296": ["02"] # USB_COMPOSITION_ID
         },
         "BG95": { # Modem Name
-            "0296": ["02"] # USB_COMPOSITION_ID
+            "0700": ["02"] # USB_COMPOSITION_ID
         }
     },
     "1bc7": { # Telit VENDOR_ID
